tmy_epw_catalogs/
-----------------
This directory contains catalog files (in practice just one file) listing the names of TMY3 files used
by this project. The catalog contains the names of the files for each WMO as listed at 
http://climate.onebuilding.org/WMO_Region_4_North_and_Central_America/USA_United_States_of_America/,
as well as the download URL for each file.